<?php

/**
 * @file
 * viewers.admin.inc
 */

/**
 * Administrative settings for viewers.
 */
function viewers_admin_settings_form() {

  $form['viewers_time'] = array(
    '#title' => t('Maximum time in sec'),
    '#description' => t('Time that a user appears on the viewers list. Default is 60 secs.'),
    '#size' => '4',
    '#type' => 'textfield',
    '#default_value' => variable_get('viewers_time', '60'),
    '#element_validate' => array('element_validate_number'),
  );

  $form['viewers_query_strings'] = array(
    '#title' => t('Do you want to support query strings?'),
    '#description' => t('If checked /node?page=1 will be different than /node?page=2. Keep in mind <br/>
      that this will increase the records in the database significantly.'),
    '#type' => 'radios',
    '#default_value' => variable_get('viewers_query_strings', 0),
    '#options' => array(
      0 => t('No'),
      1 => t('Yes'),
    ),
  );

  $form['viewers_ajax_tracking'] = array(
    '#title' => t('Do you want to track visitors/users via javascript?'),
    '#description' => t("In case you are behind a reverse proxy or having caching enabled, tracking via JS is the only way to handle anonymous tracking."),
    '#type' => 'radios',
    '#default_value' => variable_get('viewers_ajax_tracking', 1),
    '#options' => array(
      0 => t('No'),
      1 => t('Yes'),
    ),
  );

  $form['viewers_tracking'] = array(
    '#type' => 'vertical_tabs',
  );

  // Render the role overview.
  $form['viewers_tracking']['viewers_roles'] = array(
    '#type' => 'fieldset',
    '#title' => t('Roles'),
  );

  $form['viewers_tracking']['viewers_roles']['viewers_visibility_roles'] = array(
    '#type' => 'radios',
    '#title' => t('Add tracking for specific roles'),
    '#options' => array(
      t('Add to the selected roles only'),
      t('Add to every role except the selected ones'),
    ),
    '#default_value' => variable_get('viewers_visibility_roles', 0),
  );

  $form['viewers_tracking']['viewers_roles']['viewers_users_roles'] = array(
    '#type' => 'checkboxes',
    '#title' => t('Which roles to track?'),
    '#description' => t('If none of the roles are selected, all users will be tracked. If a user has any of the roles checked, that user will be tracked (or excluded, depending on the setting above).'),
    '#options' => user_roles(),
    '#default_value' => variable_get('viewers_users_roles', array('')),
  );

  // Render specific pages.
  $form['viewers_tracking']['viewers_pages'] = array(
    '#type' => 'fieldset',
    '#title' => t('Pages'),
  );

  // We don't want to reinvent the wheel. Code is part of the
  // googleanalytics.module and block.module.
  $php_access = user_access('use PHP for tracking visibility');
  $visibility = variable_get('viewers_visibility_pages', 0);
  $pages = variable_get('viewers_pages', VIEWERS_PAGES);

  if ($visibility == 2 && !$php_access) {
    $form['viewers_tracking']['viewers_pages'] = array();
    $form['viewers_tracking']['viewers_pages']['visibility'] = array('#type' => 'value', '#value' => 2);
    $form['viewers_tracking']['viewers_pages']['pages'] = array('#type' => 'value', '#value' => $pages);
  }
  else {
    $options = array(
      t('Every page except the listed pages'),
      t('The listed pages only'),
    );
    $description = t("Specify pages by using their paths. Enter one path per line.
      The '*' character is a wildcard. Example paths are %blog for the blog page and
      %blog-wildcard for every personal blog. %front is the front page.",
      array(
        '%blog' => 'blog',
        '%blog-wildcard' => 'blog/*',
        '%front' => '<front>',
      )
    );

    if (module_exists('php') && $php_access) {
      $options[] = t('Pages on which this PHP code returns <code>TRUE</code> (experts only)');
      $title = t('Pages or PHP code');
      $description .= ' ' . t('If the PHP option is chosen, enter PHP code between %php. Note that executing incorrect PHP code can break your Drupal site.', array('%php' => '<?php ?>'));
    }
    else {
      $title = t('Pages');
    }
    $form['viewers_tracking']['viewers_pages']['viewers_visibility_pages'] = array(
      '#type' => 'radios',
      '#title' => t('Add tracking to specific pages'),
      '#options' => $options,
      '#default_value' => $visibility,
    );
    $form['viewers_tracking']['viewers_pages']['viewers_pages'] = array(
      '#type' => 'textarea',
      '#title' => $title,
      '#title_display' => 'invisible',
      '#default_value' => $pages,
      '#description' => $description,
      '#rows' => 10,
    );
  }

  // Render excluded user list.
  $form['viewers_tracking']['viewers_excluded_users'] = array(
    '#type' => 'fieldset',
    '#title' => t('Excluded users'),
  );

  $form['viewers_tracking']['viewers_excluded_users']['viewers_excluded_users_list'] = array(
    '#title' => t('If you want to exclude specific users, type here their UIDs:'),
    '#type' => 'textarea',
    '#description' => t('Seperate the uids with a comma, for example 1,2,34. Keep in mind that all users typed here will be <strong>excluded</strong>, even their roles have been set to be tracked.'),
    '#default_value' => variable_get('viewers_excluded_users_list', ''),
  );

  // Render output.
  $form['viewers_tracking']['viewers_styling_output'] = array(
    '#type' => 'fieldset',
    '#title' => t('Style'),
  );

  $form['viewers_tracking']['viewers_styling_output']['viewers_text_to_display'] = array(
    '#title' => t('Text to display if there are users online'),
    '#type' => 'textfield',
    '#default_value' => variable_get('viewers_text_to_display', t('Currently !auth_total user(s): !auth and !anon_total visitor(s) online.')),
    '#description' => t('The following tokens are supported, if they have been enabled:
      <br/> - !auth_total : the number of authenticated users
      <br/> - !auth : the names of authenticated users
      <br/> - !anon_total : the number of anonymous users'),
  );

  $form['viewers_tracking']['viewers_styling_output']['viewers_text_to_display_no_users'] = array(
    '#title' => t("Text to display if there aren\'t users online"),
    '#type' => 'textfield',
    '#default_value' => variable_get('viewers_text_to_display_no_users', t('Currently no users online.')),
  );

  $form['viewers_tracking']['viewers_styling_output']['viewers_roles_to_output'] = array(
    '#title' => t('Which output do you prefer?'),
    '#type' => 'radios',
    '#default_value' => variable_get('viewers_roles_to_output', 0),
    '#options' => array(
      '0' => t('All tracked user roles'),
      '1' => t('Only authenticated'),
      '2' => t('Only anonymous'),
    ),
  );

  $form['viewers_tracking']['viewers_styling_output']['viewers_separator'] = array(
    '#title' => t('Choose separator for user list:'),
    '#type' => 'radios',
    '#default_value' => variable_get('viewers_separator', ', '),
    '#options' => array(
      ', ' => 'comma ( , )',
      ' - ' => 'hyphen ( - )',
      ' / ' => 'slash ( / )',
      ' ' => 'space (  )',
    ),
    '#states' => array(
      'visible' => array(
        ':input[name="viewers_names_to_output"]' => array('value' => '1'),
      ),
    ),
  );

  // Render Ajax settings.
  $form['viewers_tracking']['viewers_ajax_settings'] = array(
    '#type' => 'fieldset',
    '#title' => t('Ajax settings'),
  );

  $form['viewers_tracking']['viewers_ajax_settings']['viewers_ajax_status'] = array(
    '#title' => t('Do you want to enable via AJAX?'),
    '#type' => 'radios',
    '#default_value' => variable_get('viewers_ajax_status', '0'),
    '#options' => array(
      '0' => t('No'),
      '1' => t('Yes'),
    ),
  );

  $form['viewers_tracking']['viewers_ajax_settings']['viewers_ajax_timer'] = array(
    '#title' => t('AJAX refresh timer'),
    '#description' => t('Duration is in seconds.'),
    '#type' => 'textfield',
    '#default_value' => variable_get('viewers_ajax_timer', '60'),
    '#states' => array(
      'visible' => array(
        ':input[name="viewers_ajax_status"]' => array('value' => '1'),
      ),
    ),
  );

  // Render advanced settings.
  $form['viewers_tracking']['viewers_advanced_settings'] = array(
    '#type' => 'fieldset',
    '#title' => t('Advanced settings'),
  );

  $form['viewers_tracking']['viewers_advanced_settings']['viewers_clear_table'] = array(
    '#type' => 'submit',
    '#value' => t('Clear viewers table'),
    '#submit' => array('viewers_clear_table'),
  );

  $form['viewers_tracking']['viewers_advanced_settings']['viewers_delete_expired_records'] = array(
    '#type' => 'submit',
    '#value' => t('Delete expired records'),
    '#submit' => array('_viewers_delete_expired_records'),
  );

  return system_settings_form($form);
}

/**
 * Truncates the viewers table.
 */
function viewers_clear_table($form, &$form_state) {
  db_truncate('viewers')->execute();
  drupal_set_message(t('The viewers table has been truncated.'));
}
