
/**
 * @file
 * Javascript funcitonality for viewers.js.
 */

/**
 * Viewers is a small module, which builds a block showing which users are
 * viewing the same page as the current user
 */
(function($){

  /**
   * Add an extra function to the Drupal ajax object
   * which allows us to trigger an ajax response without
   * an element that triggers it.
   */
  Drupal.ajax.prototype.specifiedResponse = function() {
    var ajax = this;

    // Do not perform another ajax command if one is already in progress.
    if (ajax.ajaxing) {
      return false;
    }

    try {
      $.ajax(ajax.options);
    }
    catch (err) {
      console.log('An error occurred while attempting to process ' + ajax.options.url);
      return false;
    }

    return false;
  };

  /**
   * Define a custom ajax action not associated with an element.
   */
  var data = {
    'path' : Drupal.settings.viewers.path,
  };
  var custom_settings = {};
  custom_settings.url = '/viewers/refresh';
  custom_settings.event = 'onload';
  custom_settings.keypress = false;
  custom_settings.prevent = false;
  custom_settings.submit = data;
  Drupal.ajax['viewers_update'] = new Drupal.ajax(null, $(document.body), custom_settings);

  /**
   * Define a point to trigger our custom actions. e.g. on page load.
   */
  $(document).ready(function() {
    setInterval(function() {
      Drupal.ajax['viewers_update'].specifiedResponse();
    }, Drupal.settings.viewers.timer * 1000);
  });

})(jQuery);
